# Hamhoush SKD
this a hamhoush platform sdk

# Sample Code
```python 
    api_client = ApiClient()
    api_client.login("UserName", "Password")
    
    response = api_client.chat(bot_id="BotId",message="سلام")
    print("Chat response:", response)
```